@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::Action::FixSpec;
 {
-  $App::Magpie::Action::FixSpec::VERSION = '1.113121';
+  $App::Magpie::Action::FixSpec::VERSION = '1.113122';
 }
 # ABSTRACT: fixspec command implementation
 
@@ -49,7 +49,7 @@ sub run {
     $self->run_command( "bm -lc" ); # run -c to make sure MYMETA is generated
     my $distdir  = dir( glob "BUILD/*" );
     my $metafile;
-    foreach my $meta ( "MYMETA.yml", "META.json", "META.yml" ) {
+    foreach my $meta ( "MYMETA.json", "MYMETA.yml", "META.json", "META.yml" ) {
         next unless -e $distdir->file( $meta );
         $metafile = $distdir->file( $meta );
         last;
@@ -148,7 +148,7 @@ sub run {
         sort
         grep {
             ( /^[A-Z]+$/ && ! /^MANIFEST/ ) ||
-            m{^(Change(s|log)|(MY)?META.(json|yml)|e[gx]|(ex|s)amples?|demos?)$}i
+            m{^(Change(s|log)|MYMETA.yml|META.(json|yml)|e[gx]|(ex|s)amples?|demos?)$}i
         }
         map  { $_->basename }
         $distdir->children;
@@ -214,7 +214,7 @@ App::Magpie::Action::FixSpec - fixspec command implementation
 
 =head1 VERSION
 
-version 1.113121
+version 1.113122
 
 =head1 SYNOPSIS
 
